@@ -26,7 +26,7 @@ import time
 import kissen
 import pygame
 import random
-import logging
+#import logging
 import subprocess
 from PyQt4 import QtGui
 from PyQt4.uic import loadUi
@@ -36,6 +36,8 @@ from PyQt4.uic import loadUi
 
 pygame.init()
 random.seed()
+
+
 #Logger einrichten
 #logging.basicConfig(filename = "fartyprotokoll.log",
 #                    level = logging.INFO,
@@ -49,7 +51,6 @@ class MainWindow(QtGui.QMainWindow):
         QtGui.QMainWindow.__init__(self,parent)
        
         #MainWindow Initialisierung/Laden des Stylesheets
-      #  logging.info("Farty wurde gestartet")
         self.ui=loadUi("/opt/farty/furzkissen.ui")
         self.ui.show()
         self.ui.showFullScreen()
@@ -66,39 +67,25 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.minimize.clicked.connect(self.minimize2)
         self.ui.idea.clicked.connect(self.idea2)
         self.ui.about.clicked.connect(self.about2)
-        #self.ui.play.clicked.connect(self.play2)
-        #self.ui.vibon.toggled.connect(self.vibOn)
-        #self.ui.viboff.toggled.connect(self.vibOff)
         
         #Methoden
        
-    
     def fartrandom(self):#Zufallsmechanismus für Abspielen der Furzsounds 10-81 
         fartnumber=random.randint(10,81)
         path="/opt/farty/Furzsounds/furz0"+str(fartnumber)+".wav"
         sound=pygame.mixer.Sound(path)
         sound.play()
         pygame.time.delay(200)
-     #   logging.info("Farty hat den Sound furz0"+str(fartnumber)+".wav gefurzt")
-        
-       
-       
-        #time.sleep(1.2) #Führt nach Mehrfachklick zu ewigem Abspielen --> deaktiviert!
+
        
     def close2(self):#Methode zum Schließen des Mainwindows
-     #   logging.info("Farty wurde beendet")
         sys.exit()
         
     def minimize2(self):#Experimentell, schließt statt zu minimieren
-        try:
-    #        logging.info("Farty wurde minimiert")
-            subprocess.Popen(['dbus-send', '--type=signal', '--session', '/com/nokia/hildon_desktop', 'com.nokia.hildon_desktop.exit_app_view'])
+        subprocess.Popen(['dbus-send', '--type=signal', '--session', '/com/nokia/hildon_desktop', 'com.nokia.hildon_desktop.exit_app_view'])
                 
-        except:
-        #    logging.error("Farty konnte nicht minimiert werden!")  
          
     def idea2(self):
-    #    logging.info("Fartys Infobox wurde aufgerufen")
         QtGui.QMessageBox.about(self, "Farty the Farter:\n",
                  "Click me, in order to let me fart.\n"
                  "I can do more than 65 different\n"
@@ -106,33 +93,8 @@ class MainWindow(QtGui.QMainWindow):
                  "Have fun and keep farting ;)\n")
         
     def about2(self):
-    #    logging.info("Fartys QtAboutBox wurde aufgerufen")
         QtGui.QMessageBox.aboutQt(self)    
-        
-        
-    def vibOn(self):
-        '''
-        trigger vibration on n900
-        '''
-        self.rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,
-        self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
-        time.sleep(1)    
-        fartnumber=random.randint(10,81)
-        path="Furzsounds/furz0"+str(fartnumber)+".wav"
-        sound=pygame.mixer.Sound(path)
-        sound.play()    
-    def vibOff(self):
-        pass
-            
-    def play2(self):
-        for i in range(2,20,1):
-            fartnumber=random.randint(10,81)
-            path="Furzsounds/furz0"+str(fartnumber)+".wav"
-            sound=pygame.mixer.Sound(path)
-            sound.play() 
-            time.sleep(2)
-            i=i+2 
-            
+       
                             
     
 app = QtGui.QApplication(sys.argv)
